@@ -2,27 +2,19 @@ package Dancer::Plugin::RPC;
 use warnings;
 use strict;
 
-our $VERSION = '1.10_02';
-
-# Will be set from the request-handler for the callback scope
-our $ROUTE_INFO = {
-    plugin        => undef,        # PLUGIN_NAME,
-    endpoint      => undef,        # $endpoint,
-    rpc_method    => undef,        # $method_name,
-    full_path     => undef,        # request->path,
-    http_method   => undef,        # $http_method,
-};
+our $VERSION = '1.01';
 
 1;
 
 =head1 NAME
 
-Dancer::Plugin::RPC - Configure endpoints for XMLRPC, JSONRPC and RESTRPC procedures
+Dancer::Plugin::RPC - Configure endpoints for XMLRPC and JSONRPC procedures
 
 =head1 DESCRIPTION
 
-This module contains plugins for L<Dancer>: L<Dancer::Plugin::RPC::XMLRPC>,
-L<Dancer::Plugin::RPC::JSONRPC> and L<Dancer::Plugin::RPC::RESTRPC>.
+This module contains two plugins for L<Dancer>: L<Dancer::Plugin::RPC::XMLRPC>
+and L<Dancer::Plugin::RPC::JSONRPC>. They are plugins rather than
+Plack::Middleware.
 
 =head2 Dancer::Plugin::RPC::XMLRPC
 
@@ -34,12 +26,7 @@ the endpoint and the arguments to configure the xmlrpc-calls at this endpoint.
 This plugin exposes the new keyword C<jsonrpc> that is followed by 2 arguments:
 the endpoint and the arguments to configure the jsonrpc-calls at this endpoint.
 
-=head2 Dancer::Plugin::RPC::RESTRPC
-
-This plugin exposes the new keyword C<restrpc> that is followed by 2 arguments:
-the endpoint and the arguments to configure the restrpc-calls at this endpoint.
-
-=head2 General arguments to xmlrpc/jsonrpc/restrpc
+=head2 General arguments to xmlrpc/jsonrpc
 
 The dispatch table is build by endpoint.
 
@@ -67,8 +54,7 @@ The B<arguments> argument should be empty for this publishing type.
 
 =item publish => B<pod>
 
-The dispatch table is build by parsing the POD for C<=for xmlrpc>,
-C<=for jsonrpc> or C<=for restrpc>.
+The dispatch table is build by parsing the POD for C<=for xmlrpc> or C<=for jsonrpc>.
 
     =for xmlrpc <method_name> <sub_name>
 
@@ -113,21 +99,7 @@ Returns for success: C<< callback_success() >>
 
 Returns for failure: C<< callback_fail(error_code => $code, error_message => $msg) >>
 
-This is useful for eg ACL checking.
-
-In the scope of the callback-function you will have the variable
-C<$Dancer::RPCPlugin::ROUTE_INFO>, a hashref:
-
-    local $Dancer::RPCPlugin::ROUTE_INFO = {
-        plugin        => PLUGIN_NAME,
-        endpoint      => $endpoint,
-        rpc_method    => $method_name,
-        full_path     => request->path,
-        http_method   => $http_method,
-    };
-
-Other plugins may want to put extra information in there to help you decide if
-this request should even be honoured.
+This is useful for ACL checking.
 
 =head3 code_wrapper => $coderef
 
