@@ -2,204 +2,133 @@ package Dancer::Plugin::RPC::JSONRPC;
 use v5.10;
 use Dancer ':syntax';
 use Dancer::Plugin;
-use Scalar::Util 'blessed';
-use Time::HiRes 'time';
-
-our $VERSION = '1.09';
 
 no if $] >= 5.018, warnings => 'experimental::smartmatch';
 
-use constant PLUGIN_NAME => 'jsonrpc';
-
 use Dancer::RPCPlugin::CallbackResult;
 use Dancer::RPCPlugin::DispatchFromConfig;
 use Dancer::RPCPlugin::DispatchFromPod;
 use Dancer::RPCPlugin::DispatchItem;
 use Dancer::RPCPlugin::DispatchMethodList;
-use Dancer::RPCPlugin::ErrorResponse;
-use Dancer::RPCPlugin::FlattenData;
 
 my %dispatch_builder_map = (
     pod    => \&build_dispatcher_from_pod,
     config => \&build_dispatcher_from_config,
 );
 
-register PLUGIN_NAME ,=> sub {
+register jsonrpc => sub {
     my ($self, $endpoint, $arguments) = plugin_args(@_);
 
     my $publisher;
-    GIVEN: {
-        local $_ = $arguments->{publish} // 'config';
-        exists($dispatch_builder_map{$_}) && do {
+    given ($arguments->{publish} // 'config') {
+        when (exists $dispatch_builder_map{$_}) {
             $publisher = $dispatch_builder_map{$_};
             $arguments->{arguments} = plugin_setting() if $_ eq 'config';
-            last GIVEN;
-        };
-        do {
+        }
+        default {
             $publisher = $_;
-        };
+        }
     }
+
+    my $code_wrapper = $arguments->{code_wrapper} // sub {
+        my $code = shift;
+        my $pkg  = shift;
+        $code->(@_);
+    };
+    my $callback = $arguments->{callback};
     my $dispatcher = $publisher->($arguments->{arguments}, $endpoint);
 
     my $lister = Dancer::RPCPlugin::DispatchMethodList->new();
     $lister->set_partial(
-        protocol => PLUGIN_NAME,
+        protocol => 'jsonrpc',
         endpoint => $endpoint,
         methods  => [ sort keys %{ $dispatcher } ],
     );
 
-    my $code_wrapper = $arguments->{code_wrapper}
-        ? $arguments->{code_wrapper}
-        : sub {
-            my $code = shift;
-            my $pkg  = shift;
-            $code->(@_);
-        };
-    my $callback = $arguments->{callback};
-
-    debug("Starting jsonrpc-handler build: ", $lister);
     my $handle_call = sub {
-        my ($ct) = (split /;\s*/, request->content_type, 2);
-        if ($ct ne 'application/json') {
+        if (request->content_type ne 'application/json') {
             pass();
         }
+
         my @requests = unjson(request->body);
-        if (!exists($requests[0]->{jsonrpc}) or $requests[0]->{jsonrpc} ne "2.0") {
-            pass();
-        }
 
-        debug("[handle_jsonrpc_request] Processing: ", request->body);
-
-        content_type 'application/json';
         my @responses;
         for my $request (@requests) {
             my $method_name = $request->{method};
+            debug("[handle_jsonrpc_call] $method_name ", $request);
 
             if (!exists $dispatcher->{$method_name}) {
-                push(
-                    @responses,
-                    jsonrpc_response(
-                        $request->{id},
-                        error => {
-                            code    => -32601,
-                            message => "Method '$method_name' not found",
-                        }
-                    )
+                push @responses, jsonrpc_error_response(
+                    -32601,
+                    "Method '$method_name' not found",
+                    $request->{id}
                 );
                 next;
             }
 
-            my $method_args = $request->{params};
-
-            my $start_request = time();
-            debug("[handle_jsonrpc_call($method_name)] ", $method_args);
+            my @method_args = $request->{params};
             my Dancer::RPCPlugin::CallbackResult $continue = eval {
-                local $Dancer::RPCPlugin::ROUTE_INFO = {
-                    plugin        => PLUGIN_NAME,
-                    endpoint      => $endpoint,
-                    rpc_method    => $method_name,
-                    full_path     => request->path,
-                    http_method   => uc(request->method),
-                };
                 $callback
-                    ? $callback->(request(), $method_name, $method_args)
+                    ? $callback->(request(), $method_name, @method_args)
                     : callback_success();
             };
 
             if (my $error = $@) {
-                push(
-                    @responses,
-                    jsonrpc_response(
-                        $request->{id},
-                        error => {
-                            code    => -32500,
-                            message => $error,
-                        }
-                    )
+                push @responses, jsonrpc_error_response(
+                    500,
+                    $error,
+                    $request->{id}
                 );
                 next;
             }
-            if (!blessed($continue) || !$continue->isa('Dancer::RPCPlugin::CallbackResult')) {
-                push @responses, jsonrpc_response(
-                    $request->{id},
-                    error => {
-                        code    => -32603,
-                        message => "Internal error: 'callback_result' wrong class " . blessed($continue),
-                    }
+            if (!$continue->success) {
+                push @responses, jsonrpc_error_response(
+                    $continue->error_code,
+                    $continue->error_message,
+                    $request->{id}
                 );
                 next;
             }
-            elsif (blessed($continue) && !$continue->success) {
-                    push @responses, jsonrpc_response(
-                        $request->{id},
-                        error => {
-                            code    => $continue->error_code,
-                            message => $continue->error_message,
-                        }
-                    );
-                    next;
-            }
 
             my Dancer::RPCPlugin::DispatchItem $di = $dispatcher->{$method_name};
             my $handler = $di->code;
             my $package = $di->package;
 
             my $result = eval {
-                $code_wrapper->($handler, $package, $method_name, $method_args);
+                $code_wrapper->($handler, $package, $method_name, @method_args);
             };
-            my $error = $@;
 
-            debug("[handled_jsonrpc_request($method_name)] ", flatten_data($result));
-            info( sprintf(
-                "[RPC::JSONRPC] request for %s took %.4fs",
-                $method_name, time() - $start_request
-            ));
-            if ($error) {
-                my $error_response = blessed($error) && $error->can('as_jsonrpc_error')
-                    ? $error
-                    : error_response(
-                            error_code    => -32500,
-                            error_message => $error,
-                            error_data    => $method_args,
-                    );
-                status $error_response->return_status(PLUGIN_NAME);
-                push @responses, jsonrpc_response(
-                    $request->{id},
-                    %{ $error_response->as_jsonrpc_error },
+            debug("[handeled_jsonrpc_call] ", $result);
+            if (my $error = $@) {
+                push @responses, jsonrpc_error_response(
+                    500,
+                    $error,
+                    $request->{id}
                 );
                 next;
             }
-            if (blessed($result) && $result->can('as_jsonrpc_error')) {
-                push @responses, jsonrpc_response(
-                    $request->{id},
-                    %{ $result->as_jsonrpc_error }
-                );
-                next;
-            }
-            elsif (blessed($result)) {
-                $result = flatten_data($result);
-            }
-            push @responses, jsonrpc_response($request->{id}, result => $result);
+            push @responses, {
+                jsonrpc => '2.0',
+                result => $result,
+                exists $request->{id}
+                    ? (id => $request->{id})
+                    : (),
+            };
         }
 
         # create response
-        my $jsonise_options = {canonical => 1};
-        if (config->{encoding} && config->{encoding} =~ m{^utf-?8$}i) {
-            $jsonise_options->{utf8} = 1;
-        }
         my $response;
         if (@responses == 1) {
-            $response = to_json($responses[0], $jsonise_options);
+            $response = to_json($responses[0]);
         }
         else {
-            $response = to_json([grep {defined($_->{id})} @responses], $jsonise_options);
+            $response = to_json(\@responses);
         }
 
-        debug("[jsonrpc_response] ", $response);
+        content_type 'application/json';
         return $response;
     };
 
-    debug("setting route (jsonrpc): $endpoint ", $lister);
     post $endpoint, $handle_call;
 };
 
@@ -217,24 +146,25 @@ sub unjson {
     return @requests;
 }
 
-sub jsonrpc_response {
-    my ($id, $type, $data) = @_;
-
+sub jsonrpc_error_response {
+    my ($code, $message, $id) = @_;
     return {
         jsonrpc => '2.0',
-        id      => $id,
-        $type  => $data,
+        error => {
+            code    => $code,
+            message => $message,
+        },
+        defined $id ? (id => $id) : (),
     };
 }
 
 sub build_dispatcher_from_pod {
-    my ($pkgs, $endpoint) = @_;
+    my ($pkgs) = @_;
     debug("[build_dispatcher_from_pod]");
 
     return dispatch_table_from_pod(
-        plugin   => PLUGIN_NAME,
         packages => $pkgs,
-        endpoint => $endpoint,
+        label    => 'xmlrpc',
     );
 }
 
@@ -243,12 +173,11 @@ sub build_dispatcher_from_config {
     debug("[build_dispatcher_from_config] $endpoint");
 
     return dispatch_table_from_config(
-        plugin   => PLUGIN_NAME,
+        key      => 'jsonrpc',
         config   => $config,
         endpoint => $endpoint,
     );
 }
-
 register_plugin;
 1;
 
@@ -298,7 +227,7 @@ The callback will be called just before the actual rpc-code is called from the
 dispatch table. The arguments are positional: (full_request, method_name).
 
     my Dancer::RPCPlugin::CallbackResult $continue = $callback
-        ? $callback->(request(), $method_name, $method_args)
+        ? $callback->(request(), $method_name, @method_args)
         : callback_success();
 
 The callback should return a L<Dancer::RPCPlugin::CallbackResult> instance:
@@ -409,9 +338,9 @@ actual sub-name in the current package.
 
 Deserializes the string as Perl-datastructure.
 
-=head2 jsonrpc_response
+=head2 jsonrpc_error_response
 
-Returns a jsonrpc response as a hashref.
+Returns a jsonrpc error response as a hashref.
 
 =head2 build_dispatcher_from_config
 
@@ -425,12 +354,4 @@ Creates a (partial) dispatch table from data provided in POD.
 
 (c) MMXVI - Abe Timmerman <abeltje@cpan.org>.
 
-=begin podcover_can_suck
-
-=head2 PLUGIN_NAME
-
-L<Test::Pod::Coverage> fails this test without this section :'(
-
-=end podcover_can_suck
-
 =cut
